var searchData=
[
  ['k_5fbishop',['K_BISHOP',['../kanjiCode_8h.html#a96244a4ff62c588661d0729dd79bbbb0',1,'kanjiCode.h']]],
  ['k_5fbishop_5fr',['K_BISHOP_R',['../kanjiCode_8h.html#af5578b188964c30a0ee2cc97604628f5',1,'kanjiCode.h']]],
  ['k_5fblack',['K_BLACK',['../kanjiCode_8h.html#a8fb311774990405fe4f77efd56874cf0',1,'kanjiCode.h']]],
  ['k_5fblack_5fsign',['K_BLACK_SIGN',['../kanjiCode_8h.html#af82e40120fc30053f9ec6dffb2301143',1,'kanjiCode.h']]],
  ['k_5fblack_5fstand',['K_BLACK_STAND',['../kanjiCode_8h.html#a19a62a484427431100bb7933c3aee93b',1,'kanjiCode.h']]],
  ['k_5fcolon',['K_COLON',['../kanjiCode_8h.html#ab646154c5b0ce2670bcbfe365d2f2114',1,'kanjiCode.h']]],
  ['k_5fdan',['K_DAN',['../kanjiCode_8h.html#a509a14ec4b17de5a0cdfc4fe8518f714',1,'kanjiCode.h']]],
  ['k_5ffunari',['K_FUNARI',['../kanjiCode_8h.html#a98558ada4648ad00864bb9b1c6db213c',1,'kanjiCode.h']]],
  ['k_5fgold',['K_GOLD',['../kanjiCode_8h.html#a3a53832600910f6cddbc1778df6dd7cd',1,'kanjiCode.h']]],
  ['k_5fgold_5fr',['K_GOLD_R',['../kanjiCode_8h.html#a8658dfb41fa52f4b25be8eb70fa260f9',1,'kanjiCode.h']]],
  ['k_5fhenka',['K_HENKA',['../kanjiCode_8h.html#a2ffd19a80a6a5743203fb108b4727808',1,'kanjiCode.h']]],
  ['k_5fhidari',['K_HIDARI',['../kanjiCode_8h.html#af1278d2a9a9d6e11d185aa0b4caefde2',1,'kanjiCode.h']]],
  ['k_5fhiku',['K_HIKU',['../kanjiCode_8h.html#a99490782da15c552e812f0890a32d97a',1,'kanjiCode.h']]],
  ['k_5fjoryuu',['K_JORYUU',['../kanjiCode_8h.html#aac073542983e9d87ef0010ad7040dd3c',1,'kanjiCode.h']]],
  ['k_5fk1',['K_K1',['../kanjiCode_8h.html#a9ccee083566aac1bcd80a4055fce55c0',1,'kanjiCode.h']]],
  ['k_5fk10',['K_K10',['../kanjiCode_8h.html#aa112d78b37b63d8493de46fc0f83b12b',1,'kanjiCode.h']]],
  ['k_5fk11',['K_K11',['../kanjiCode_8h.html#a661ecf30f4e8766b0132d8306baac85e',1,'kanjiCode.h']]],
  ['k_5fk12',['K_K12',['../kanjiCode_8h.html#af9d05410004c92f8b0f05518c1f9faf0',1,'kanjiCode.h']]],
  ['k_5fk13',['K_K13',['../kanjiCode_8h.html#a0b628c2469990926db2288c585b881ea',1,'kanjiCode.h']]],
  ['k_5fk14',['K_K14',['../kanjiCode_8h.html#a40ee9c66d65c599a742377a82c088ce2',1,'kanjiCode.h']]],
  ['k_5fk15',['K_K15',['../kanjiCode_8h.html#a488b94a696e74f06936ebfa5d6f282ce',1,'kanjiCode.h']]],
  ['k_5fk16',['K_K16',['../kanjiCode_8h.html#af3a60f4b0214075c3e7ddeb972e05875',1,'kanjiCode.h']]],
  ['k_5fk17',['K_K17',['../kanjiCode_8h.html#abded51303618a4c4b13c36ccfd8c7ff4',1,'kanjiCode.h']]],
  ['k_5fk18',['K_K18',['../kanjiCode_8h.html#a0b44f60cb59701f90069c1fa46afb61d',1,'kanjiCode.h']]],
  ['k_5fk2',['K_K2',['../kanjiCode_8h.html#ae9d007a618bc0037e434d8583f65150c',1,'kanjiCode.h']]],
  ['k_5fk3',['K_K3',['../kanjiCode_8h.html#a3f890a9291c7980486c8d0eac57c27ac',1,'kanjiCode.h']]],
  ['k_5fk4',['K_K4',['../kanjiCode_8h.html#a83f5b39057deb85e7096116bf34009f3',1,'kanjiCode.h']]],
  ['k_5fk5',['K_K5',['../kanjiCode_8h.html#a9bb56f5decda0b37faf1c8a3f8759a55',1,'kanjiCode.h']]],
  ['k_5fk6',['K_K6',['../kanjiCode_8h.html#af147e51e16fa23bade31a474b9791f06',1,'kanjiCode.h']]],
  ['k_5fk7',['K_K7',['../kanjiCode_8h.html#a43a727f8459b0e6bf496b42a12fe7cc0',1,'kanjiCode.h']]],
  ['k_5fk8',['K_K8',['../kanjiCode_8h.html#a71615aeebbad243a89c5f94bdc6d8035',1,'kanjiCode.h']]],
  ['k_5fk9',['K_K9',['../kanjiCode_8h.html#a757674d28fe4f31b56ebd69844b76ece',1,'kanjiCode.h']]],
  ['k_5fkaishi',['K_KAISHI',['../kanjiCode_8h.html#a021f0c7aa895a4eef0ff6dda596742b0',1,'kanjiCode.h']]],
  ['k_5fkanmuri',['K_KANMURI',['../kanjiCode_8h.html#a494b2ee497492b6a8fb409db52013f70',1,'kanjiCode.h']]],
  ['k_5fki',['K_KI',['../kanjiCode_8h.html#a236b089f026212f5f3b8a6b37b1e7a54',1,'kanjiCode.h']]],
  ['k_5fkifu',['K_KIFU',['../kanjiCode_8h.html#aa4e52df7e36cf9111336ec84535c39fd',1,'kanjiCode.h']]],
  ['k_5fking',['K_KING',['../kanjiCode_8h.html#a5e0fdff5e995195a193631b17a109267',1,'kanjiCode.h']]],
  ['k_5fking2',['K_KING2',['../kanjiCode_8h.html#a312443172a885f4b20f63e1d5513590a',1,'kanjiCode.h']]],
  ['k_5fking_5fr',['K_KING_R',['../kanjiCode_8h.html#aca18613660ef065ed443f3c5a72790b1',1,'kanjiCode.h']]],
  ['k_5fkisen',['K_KISEN',['../kanjiCode_8h.html#af2ec7185e286e4bd27c9caec00c3d59f',1,'kanjiCode.h']]],
  ['k_5fknight',['K_KNIGHT',['../kanjiCode_8h.html#a045477081bfe60ee7626043e725ce4b0',1,'kanjiCode.h']]],
  ['k_5fknight_5fr',['K_KNIGHT_R',['../kanjiCode_8h.html#a72dc5f7ac0c605c894d88c1cc97e5289',1,'kanjiCode.h']]],
  ['k_5fkurai',['K_KURAI',['../kanjiCode_8h.html#a3f915706e31b0c96ab70fce15ab6a4e9',1,'kanjiCode.h']]],
  ['k_5flance',['K_LANCE',['../kanjiCode_8h.html#a417ab87896c5571ad94dab369a68c996',1,'kanjiCode.h']]],
  ['k_5flance_5fr',['K_LANCE_R',['../kanjiCode_8h.html#a926f981fddd3158969269db7f1486770',1,'kanjiCode.h']]],
  ['k_5fmeijin',['K_MEIJIN',['../kanjiCode_8h.html#ae53f7780e634f89c6ae9d4f59bf27a81',1,'kanjiCode.h']]],
  ['k_5fmigi',['K_MIGI',['../kanjiCode_8h.html#aafe9ff91233b339ede3b26c608aed92c',1,'kanjiCode.h']]],
  ['k_5fmochigoma',['K_MOCHIGOMA',['../kanjiCode_8h.html#a960dc59deca6a0045a21b10464b21e36',1,'kanjiCode.h']]],
  ['k_5fnakaguro',['K_NAKAGURO',['../kanjiCode_8h.html#a074d738ef0214659c89d7ffbcb2c5d7b',1,'kanjiCode.h']]],
  ['k_5fnaru',['K_NARU',['../kanjiCode_8h.html#a07bbf0e49ed775684f4352d51f351aae',1,'kanjiCode.h']]],
  ['k_5fnashi',['K_NASHI',['../kanjiCode_8h.html#a74a049d296110678444cee537fe95635',1,'kanjiCode.h']]],
  ['k_5fnichiji',['K_NICHIJI',['../kanjiCode_8h.html#aae15e2d48c9df3cfeb3cc58356402c00',1,'kanjiCode.h']]],
  ['k_5fonazi',['K_ONAZI',['../kanjiCode_8h.html#a810d848f6424a2b383aafb2bf7af6b18',1,'kanjiCode.h']]],
  ['k_5fpass',['K_PASS',['../kanjiCode_8h.html#a4960b4eb1c2dd2c0b1b23d9c46c82e96',1,'kanjiCode.h']]],
  ['k_5fpawn',['K_PAWN',['../kanjiCode_8h.html#a60c4cf7e0a07d5df9e48ee99786a4e4e',1,'kanjiCode.h']]],
  ['k_5fpawn_5fr',['K_PAWN_R',['../kanjiCode_8h.html#aebffbf63da8318625aa5dd6f138aad6c',1,'kanjiCode.h']]],
  ['k_5fpbishop',['K_PBISHOP',['../kanjiCode_8h.html#a98b840a07bfbad061885f9df227af5f3',1,'kanjiCode.h']]],
  ['k_5fpbishop_5fr',['K_PBISHOP_R',['../kanjiCode_8h.html#ae645222bec7aeba995ffc6231305d691',1,'kanjiCode.h']]],
  ['k_5fpknight',['K_PKNIGHT',['../kanjiCode_8h.html#a9dfdcd01f1ee83a86ea4607b6d046a24',1,'kanjiCode.h']]],
  ['k_5fpknight_5fd',['K_PKNIGHT_D',['../kanjiCode_8h.html#a20cc8d89c418bd780e2efeb6b668f4c1',1,'kanjiCode.h']]],
  ['k_5fpknight_5fr',['K_PKNIGHT_R',['../kanjiCode_8h.html#a95435d563943dd553e915c0f68afa5ac',1,'kanjiCode.h']]],
  ['k_5fplance',['K_PLANCE',['../kanjiCode_8h.html#a33a9b91b6f6d387072f326d3ec925579',1,'kanjiCode.h']]],
  ['k_5fplance_5fd',['K_PLANCE_D',['../kanjiCode_8h.html#af66d39be15346a5196df70243ca5534e',1,'kanjiCode.h']]],
  ['k_5fplance_5fr',['K_PLANCE_R',['../kanjiCode_8h.html#a35518267d42d8008cc7b7e2681474a54',1,'kanjiCode.h']]],
  ['k_5fppawn',['K_PPAWN',['../kanjiCode_8h.html#a81198f7804b24bf33bd2b7cc61448cff',1,'kanjiCode.h']]],
  ['k_5fppawn_5fr',['K_PPAWN_R',['../kanjiCode_8h.html#a78a731eea92127c042c0677133f78b3b',1,'kanjiCode.h']]],
  ['k_5fprook',['K_PROOK',['../kanjiCode_8h.html#abefee95beb3da2dfbba9c01e9c1c0057',1,'kanjiCode.h']]],
  ['k_5fprook2',['K_PROOK2',['../kanjiCode_8h.html#a251392587535310d06c7b358cb1dd82d',1,'kanjiCode.h']]],
  ['k_5fprook_5fr',['K_PROOK_R',['../kanjiCode_8h.html#a1e13350005f1d2282973da0e60944b02',1,'kanjiCode.h']]],
  ['k_5fpsilver',['K_PSILVER',['../kanjiCode_8h.html#a0014ed37702d8e90ac409623ae84c3b2',1,'kanjiCode.h']]],
  ['k_5fpsilver_5fd',['K_PSILVER_D',['../kanjiCode_8h.html#a08e69772ca3529ff4fff6248b3794b5c',1,'kanjiCode.h']]],
  ['k_5fpsilver_5fr',['K_PSILVER_R',['../kanjiCode_8h.html#a7e6e828d39dd87a1ef9dbce1d90a0f28',1,'kanjiCode.h']]],
  ['k_5fr1',['K_R1',['../kanjiCode_8h.html#ae8de5c8d07f80eee2a750492c5b6702b',1,'kanjiCode.h']]],
  ['k_5fr2',['K_R2',['../kanjiCode_8h.html#a1db1705c0fb16fa74f907a72c6e6b90b',1,'kanjiCode.h']]],
  ['k_5fr3',['K_R3',['../kanjiCode_8h.html#adcd0d009112160a617e200a982ee0542',1,'kanjiCode.h']]],
  ['k_5fr4',['K_R4',['../kanjiCode_8h.html#a16227441cbd35fce63f9a9d016c5ba57',1,'kanjiCode.h']]],
  ['k_5fr5',['K_R5',['../kanjiCode_8h.html#a1f7c89164aa7fd96eeb5738ada875a65',1,'kanjiCode.h']]],
  ['k_5fr6',['K_R6',['../kanjiCode_8h.html#aa64c81b34bfe30eb2342a9d9fb48b30f',1,'kanjiCode.h']]],
  ['k_5fr7',['K_R7',['../kanjiCode_8h.html#a78588f651372b3694647d15276a90bdd',1,'kanjiCode.h']]],
  ['k_5fr8',['K_R8',['../kanjiCode_8h.html#a6b6724a5a4814e97ae15ecb9db45aa63',1,'kanjiCode.h']]],
  ['k_5fr9',['K_R9',['../kanjiCode_8h.html#ae1ef091a3c74b571b352322a39c4c368',1,'kanjiCode.h']]],
  ['k_5fresign',['K_RESIGN',['../kanjiCode_8h.html#a44f55ab47deaebd9807729aaa9e9bc0f',1,'kanjiCode.h']]],
  ['k_5frook',['K_ROOK',['../kanjiCode_8h.html#a56b760bcf63fc41626644e430af31512',1,'kanjiCode.h']]],
  ['k_5frook_5fr',['K_ROOK_R',['../kanjiCode_8h.html#ad303d5c73847951130dd4429130f0b29',1,'kanjiCode.h']]],
  ['k_5fsei',['K_SEI',['../kanjiCode_8h.html#a45932aeb502fa80edcc42d6edf58e5e6',1,'kanjiCode.h']]],
  ['k_5fsenkei',['K_SENKEI',['../kanjiCode_8h.html#afdfec22380a3c35b18ce4eb7901a9f27',1,'kanjiCode.h']]],
  ['k_5fshita',['K_SHITA',['../kanjiCode_8h.html#a5d4f071dd476da88c2c58e8e32739480',1,'kanjiCode.h']]],
  ['k_5fshou',['K_SHOU',['../kanjiCode_8h.html#aa52c1ff7036ce8515a8e97ee7af36223',1,'kanjiCode.h']]],
  ['k_5fsilver',['K_SILVER',['../kanjiCode_8h.html#ab901f3347c61146ce75e5dbcf2dc380e',1,'kanjiCode.h']]],
  ['k_5fsilver_5fr',['K_SILVER_R',['../kanjiCode_8h.html#a7ccb4cfb7633ad1e4c2a84c36a652562',1,'kanjiCode.h']]],
  ['k_5fspace',['K_SPACE',['../kanjiCode_8h.html#a4cb0beb465c7f519de64883d9615f2fc',1,'kanjiCode.h']]],
  ['k_5fsugu',['K_SUGU',['../kanjiCode_8h.html#aed0c7aa81ff96133196727c5618cb260',1,'kanjiCode.h']]],
  ['k_5fteaiwari',['K_TEAIWARI',['../kanjiCode_8h.html#a5d3b4c969be77ed78acde66828274bfe',1,'kanjiCode.h']]],
  ['k_5ftesuu',['K_TESUU',['../kanjiCode_8h.html#a9d7adb1811504b12f73750b3993964b0',1,'kanjiCode.h']]],
  ['k_5ftoryo',['K_TORYO',['../kanjiCode_8h.html#aeef3e44d7f1afad734eda47762d90c8b',1,'kanjiCode.h']]],
  ['k_5ftsumero',['K_TSUMERO',['../kanjiCode_8h.html#a717b9a044f9492e2f205715ca59ab1ca',1,'kanjiCode.h']]],
  ['k_5fue',['K_UE',['../kanjiCode_8h.html#af8aac57ecfd0fc8b90715d6f726b2a04',1,'kanjiCode.h']]],
  ['k_5futsu',['K_UTSU',['../kanjiCode_8h.html#a8b5565dbd2050af09f94ebe73aada41f',1,'kanjiCode.h']]],
  ['k_5fwhite',['K_WHITE',['../kanjiCode_8h.html#aae181e106ada27cb72c0bc523c6f870a',1,'kanjiCode.h']]],
  ['k_5fwhite_5fsign',['K_WHITE_SIGN',['../kanjiCode_8h.html#ac41ad890e560c76c8d9c8d99710fb24a',1,'kanjiCode.h']]],
  ['k_5fwhite_5fstand',['K_WHITE_STAND',['../kanjiCode_8h.html#a89c3a2e73c2a2dc2e18fa829e898146d',1,'kanjiCode.h']]],
  ['k_5fyoru',['K_YORU',['../kanjiCode_8h.html#a57c0644154a4a5588f560e592b6a9072',1,'kanjiCode.h']]],
  ['k_5fyuku',['K_YUKU',['../kanjiCode_8h.html#af97792508fa1c054113f02dec770386c',1,'kanjiCode.h']]],
  ['k_5fza',['K_ZA',['../kanjiCode_8h.html#ad0a4cc16251ac126f366a22b26aa52ae',1,'kanjiCode.h']]],
  ['kachi',['KACHI',['../namespaceosl_1_1record.html#a3fd01e666b35c0d7fe5b10b78d81e75fa687ff0688a52f4d0eee205d8bf303251',1,'osl::record']]],
  ['kakinoki_2dto_2dcsa_2ecc',['kakinoki-to-csa.cc',['../kakinoki-to-csa_8cc.html',1,'']]],
  ['kakinoki_2ecc',['kakinoki.cc',['../kakinoki_8cc.html',1,'']]],
  ['kakinoki_2eh',['kakinoki.h',['../kakinoki_8h.html',1,'']]],
  ['kakinoki_5ffalse_5fbranch_5fsearch',['KAKINOKI_FALSE_BRANCH_SEARCH',['../dfpn_8cc.html#af60e42e37a8ae2ec36f4d3b33db3f187',1,'dfpn.cc']]],
  ['kakinokifile',['KakinokiFile',['../classosl_1_1record_1_1kakinoki_1_1KakinokiFile.html#a2e039eb82611edbad22ccba091794d97',1,'osl::record::kakinoki::KakinokiFile']]],
  ['kakinokifile',['KakinokiFile',['../classosl_1_1record_1_1kakinoki_1_1KakinokiFile.html',1,'osl::record::kakinoki']]],
  ['kakinokiioerror',['KakinokiIOError',['../structosl_1_1record_1_1kakinoki_1_1KakinokiIOError.html',1,'osl::record::kakinoki']]],
  ['kakinokiioerror',['KakinokiIOError',['../structosl_1_1record_1_1kakinoki_1_1KakinokiIOError.html#aba57a944946a78baddcd1ba9144a9160',1,'osl::record::kakinoki::KakinokiIOError']]],
  ['kakinokiparseline',['kakinokiParseLine',['../namespaceosl_1_1record.html#a44bbced169b1fcea32cf734059b4a0ac',1,'osl::record']]],
  ['kanji',['kanji',['../classosl_1_1record_1_1Characters.html#add66e0e5c5a7b3a1b99847fdceaf5fcf',1,'osl::record::Characters::kanji(const PtypeO &amp;ptypeo) const '],['../classosl_1_1record_1_1Characters.html#a61d3c266bae3477bed0259ce2d0c93d7',1,'osl::record::Characters::kanji(Ptype ptype) const ']]],
  ['kanjicode_2eh',['kanjiCode.h',['../kanjiCode_8h.html',1,'']]],
  ['kanjimove',['KanjiMove',['../classosl_1_1record_1_1KanjiMove.html#a136860318a3bb4cda69b96a12ae1d6dd',1,'osl::record::KanjiMove']]],
  ['kanjimove',['KanjiMove',['../classosl_1_1record_1_1KanjiMove.html',1,'osl::record']]],
  ['kanjimove_2ecc',['kanjiMove.cc',['../kanjiMove_8cc.html',1,'']]],
  ['kanjimove_2eh',['kanjiMove.h',['../kanjiMove_8h.html',1,'']]],
  ['kanjinumber',['kanjiNumber',['../namespaceosl_1_1record.html#a7f88d3e418b76a5f054a65f09e602cde',1,'osl::record']]],
  ['kanjiprint',['KanjiPrint',['../classosl_1_1record_1_1KanjiPrint.html',1,'osl::record']]],
  ['kanjiprint',['KanjiPrint',['../classosl_1_1record_1_1KanjiPrint.html#a57b3a0b24c0618e5476198d3c8a6d264',1,'osl::record::KanjiPrint']]],
  ['kanjiprint_2ecc',['kanjiPrint.cc',['../kanjiPrint_8cc.html',1,'']]],
  ['kanjiprint_2eh',['kanjiPrint.h',['../kanjiPrint_8h.html',1,'']]],
  ['karanari',['Karanari',['../classosl_1_1rating_1_1Karanari.html#add59650d418c9dff1bc4fdaaaa59eace',1,'osl::rating::Karanari']]],
  ['karanari',['Karanari',['../classosl_1_1rating_1_1Karanari.html',1,'osl::rating']]],
  ['karanari_2eh',['karanari.h',['../karanari_8h.html',1,'']]],
  ['karanarigroup',['KaranariGroup',['../structosl_1_1rating_1_1KaranariGroup.html#af672fa8ab86b6c819e9852a58e0b51ad',1,'osl::rating::KaranariGroup']]],
  ['karanarigroup',['KaranariGroup',['../structosl_1_1rating_1_1KaranariGroup.html',1,'osl::rating']]],
  ['keepmax',['KeepMax',['../structKeepMax.html',1,'KeepMax'],['../structKeepMax.html#ad89b7a48342785104cc67538e242cabb',1,'KeepMax::KeepMax()']]],
  ['keepmin',['KeepMin',['../structKeepMin.html',1,'KeepMin'],['../structKeepMin.html#afd0fad62b7809a04b0d25cc28978ea54',1,'KeepMin::KeepMin()']]],
  ['key',['key',['../structosl_1_1checkmate_1_1Dfpn_1_1ProofOracle.html#a3a3d951fa23fa2eb019137982bce7c41',1,'osl::checkmate::Dfpn::ProofOracle::key()'],['../classosl_1_1hash_1_1HashGenTable.html#a5bb93f9b22e42480e436988e3c4a177e',1,'osl::hash::HashGenTable::key()'],['../classosl_1_1ntesuki_1_1NtesukiRecord.html#a9c5ba2ccab8a8c8009ceeb1fbad6d482',1,'osl::ntesuki::NtesukiRecord::key()']]],
  ['keymap_5ft',['keymap_t',['../classosl_1_1record_1_1CheckDuplicate.html#a6a5bd5d7e2c641baeb3151f5793acdf8',1,'osl::record::CheckDuplicate']]],
  ['keys',['keys',['../classosl_1_1record_1_1CheckDuplicate.html#a59a1c7f450a067e7bbe8fc33117df870',1,'osl::record::CheckDuplicate']]],
  ['keytoindex',['keyToIndex',['../classosl_1_1checkmate_1_1DfpnTable.html#a3ecadee2595f018cb2dbf9b4f8c204b6',1,'osl::checkmate::DfpnTable::keyToIndex()'],['../structosl_1_1container_1_1GeneralSimpleHashTable_1_1Table.html#a8a2b836243bd3ae1c7eb86ec7cf7a532',1,'osl::container::GeneralSimpleHashTable::Table::keyToIndex()']]],
  ['kfendpredictor',['KfendPredictor',['../classosl_1_1threatmate_1_1KfendPredictor.html',1,'osl::threatmate']]],
  ['kfendpredictor_2ecc',['kfendPredictor.cc',['../kfendPredictor_8cc.html',1,'']]],
  ['kfendpredictor_2eh',['kfendPredictor.h',['../kfendPredictor_8h.html',1,'']]],
  ['ki2_2ecc',['ki2.cc',['../ki2_8cc.html',1,'']]],
  ['ki2_2eh',['ki2.h',['../ki2_8h.html',1,'']]],
  ['ki2currentinfo',['ki2currentinfo',['../classosl_1_1game__playing_1_1UsiResponse.html#a424afe15c15bfcdb2086524c00866432',1,'osl::game_playing::UsiResponse']]],
  ['ki2file',['Ki2File',['../classosl_1_1record_1_1ki2_1_1Ki2File.html#afc1e9c9c5e4ef72b578d1ac0dc00f286',1,'osl::record::ki2::Ki2File']]],
  ['ki2file',['Ki2File',['../classosl_1_1record_1_1ki2_1_1Ki2File.html',1,'osl::record::ki2']]],
  ['ki2ioerror',['Ki2IOError',['../structosl_1_1record_1_1ki2_1_1Ki2IOError.html#a1bcf3981af4a88e85464cbf41c550ff4',1,'osl::record::ki2::Ki2IOError']]],
  ['ki2ioerror',['Ki2IOError',['../structosl_1_1record_1_1ki2_1_1Ki2IOError.html',1,'osl::record::ki2']]],
  ['ki2ioerror_2eh',['ki2IOError.h',['../ki2IOError_8h.html',1,'']]],
  ['ki2moves',['ki2moves',['../classosl_1_1game__playing_1_1UsiResponse.html#a1f04f6827269872912788b7713a5be3c',1,'osl::game_playing::UsiResponse']]],
  ['kifcharacters',['KIFCharacters',['../structosl_1_1record_1_1KIFCharacters.html',1,'osl::record']]],
  ['kifu_2dto_2dmyshogi_2ecc',['kifu-to-myshogi.cc',['../kifu-to-myshogi_8cc.html',1,'']]],
  ['killer',['KILLER',['../structosl_1_1search_1_1AlphaBeta2Common.html#ad23329d06ae485b6b22ec9c4c6054ef2a0aff1d776cb51e5bba5a3737c41453d9',1,'osl::search::AlphaBeta2Common::KILLER()'],['../classosl_1_1search_1_1AlphaBeta3.html#a1cd6db8daa5d6a3faa04681a697ef332af0de70ae865c05046590342560966412',1,'osl::search::AlphaBeta3::Killer()']]],
  ['killer_5fmoves',['killer_moves',['../classosl_1_1search_1_1BigramKillerMove.html#a6d5892c43456c5bd037bfe12315cfcc9',1,'osl::search::BigramKillerMove::killer_moves()'],['../classosl_1_1search_1_1KillerMoveTable.html#a2d7c5e5ac7c9243219bf1f13c9d77f61',1,'osl::search::KillerMoveTable::killer_moves()'],['../structosl_1_1search_1_1SearchState2Shared.html#ad2ed4163722cea8f9cdb6e4d008ab1a8',1,'osl::search::SearchState2Shared::killer_moves()']]],
  ['killer_5ft',['killer_t',['../structosl_1_1search_1_1AlphaBeta2Common.html#a82cabaae34a5cfd0b1e5b25a9f166eb7',1,'osl::search::AlphaBeta2Common']]],
  ['killermove',['KillerMove',['../structosl_1_1search_1_1RealizationProbability.html#a2a9770a8727567f3c14b02522c386c63a082c5d80f32d18165d4a47169766b2fe',1,'osl::search::RealizationProbability::KillerMove()'],['../structosl_1_1search_1_1FullWidthMoveProbability.html#ab54e4d7c9a032716d6d17f53e7b52bc6a557ebd4b753ec6290f29a15ca0a26783',1,'osl::search::FullWidthMoveProbability::KillerMove()']]],
  ['killermovemax',['KillerMoveMax',['../classosl_1_1search_1_1KillerMoveTable.html#a81d859f9036dc5035cedb762517962b8',1,'osl::search::KillerMoveTable']]],
  ['killermovetable',['KillerMoveTable',['../classosl_1_1search_1_1KillerMoveTable.html#a2b21624032ca2d86002091f778b2333c',1,'osl::search::KillerMoveTable']]],
  ['killermovetable',['KillerMoveTable',['../classosl_1_1search_1_1KillerMoveTable.html',1,'osl::search']]],
  ['killermovetable_2ecc',['killerMoveTable.cc',['../killerMoveTable_8cc.html',1,'']]],
  ['killermovetable_2eh',['killerMoveTable.h',['../killerMoveTable_8h.html',1,'']]],
  ['killers',['killers',['../structosl_1_1search_1_1AlphaBeta2Common.html#ae6d693e95b035da716bf343792996678',1,'osl::search::AlphaBeta2Common']]],
  ['king',['king',['../structosl_1_1checkmate_1_1Dfpn_1_1Tree.html#ae310870d171190ce8235a1232f69a66a',1,'osl::checkmate::Dfpn::Tree::king()'],['../namespaceosl.html#a0a6e5b44dc90a9ee7b40ddce1e90b660a76f0ad48ebf870acf30ca5db728842d4',1,'osl::KING()']]],
  ['king25_5fboth_5fside',['KING25_BOTH_SIDE',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238aada3ac3a3d355d40705414ff1f4f34f4',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo::KING25_BOTH_SIDE()'],['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a4e50955f2b68346e2b45d0e829bea078',1,'osl::eval::ml::OpenMidEndingEval::king25_both_side()']]],
  ['king25_5feffect3',['KING25_EFFECT3',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238ab52266cd980f226a4c0422decd85f409',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo']]],
  ['king25_5feffect_5fattack',['KING25_EFFECT_ATTACK',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a8308821528d2cf0db3b11b7718f8338fa7ae35dcf7577b727aaba89416fca5caa',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo']]],
  ['king25_5feffect_5fcount_5fcombination',['KING25_EFFECT_COUNT_COMBINATION',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238aa4fd477d77bac171eebf82d95089e02d',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo']]],
  ['king25_5feffect_5fdefense',['KING25_EFFECT_DEFENSE',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238a7f98376c3e87f14829d672dec8f818bb',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo']]],
  ['king25_5feffect_5feach',['KING25_EFFECT_EACH',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238aab617d94aa8326a501f422e711b94f9c',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo::KING25_EFFECT_EACH()'],['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a2a562217bd2eb749906222d5f105b524',1,'osl::eval::ml::OpenMidEndingEval::king25_effect_each()']]],
  ['king25_5feffect_5fsupported',['KING25_EFFECT_SUPPORTED',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238a9f570c93d095a6540cf2a3ae792d08b8',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo']]],
  ['king25_5fmobility',['KING25_MOBILITY',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238a85b9eb94f70782a3de520f55687e043f',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo']]],
  ['king25bothside',['King25BothSide',['../classosl_1_1eval_1_1ml_1_1King25BothSide.html',1,'osl::eval::ml']]],
  ['king25bothsidex',['King25BothSideX',['../classosl_1_1eval_1_1ml_1_1King25BothSide.html#a8b0a0e3dcb97a927d16347f660f0be20',1,'osl::eval::ml::King25BothSide']]],
  ['king25bothsidex',['King25BothSideX',['../classosl_1_1eval_1_1ml_1_1King25BothSideX.html',1,'osl::eval::ml']]],
  ['king25bothsidey',['King25BothSideY',['../classosl_1_1eval_1_1ml_1_1King25BothSideY.html',1,'osl::eval::ml']]],
  ['king25bothsidey',['King25BothSideY',['../classosl_1_1eval_1_1ml_1_1King25BothSide.html#a417dc7c1d6f178ff24765f6eaa6d85b2',1,'osl::eval::ml::King25BothSide']]],
  ['king25effect',['King25Effect',['../classosl_1_1eval_1_1ml_1_1King25Effect.html',1,'osl::eval::ml']]],
  ['king25effect2',['King25Effect2',['../classosl_1_1eval_1_1ml_1_1King25Effect2.html',1,'osl::eval::ml']]],
  ['king25effect3',['King25Effect3',['../classosl_1_1eval_1_1ml_1_1King25Effect3.html',1,'osl::eval::ml']]],
  ['king25effect3y',['King25Effect3Y',['../classosl_1_1eval_1_1ml_1_1King25Effect3Y.html',1,'osl::eval::ml']]],
  ['king25effect3y',['King25Effect3Y',['../classosl_1_1eval_1_1ml_1_1King25Effect3.html#a700a43829f6ccc9d2b42814b77fe65f0',1,'osl::eval::ml::King25Effect3']]],
  ['king25effectattack',['King25EffectAttack',['../classosl_1_1eval_1_1ml_1_1King25EffectAttack.html',1,'osl::eval::ml']]],
  ['king25effectboth',['King25EffectBoth',['../classosl_1_1eval_1_1ml_1_1King25EffectBoth.html',1,'osl::eval::ml']]],
  ['king25effectcountcombination',['King25EffectCountCombination',['../classosl_1_1eval_1_1ml_1_1King25EffectCountCombination.html',1,'osl::eval::ml']]],
  ['king25effectcountcombinationy',['King25EffectCountCombinationY',['../classosl_1_1eval_1_1ml_1_1King25EffectCountCombination.html#ae30d2b6d6c829bd5752431ee250685db',1,'osl::eval::ml::King25EffectCountCombination']]],
  ['king25effectcountcombinationy',['King25EffectCountCombinationY',['../classosl_1_1eval_1_1ml_1_1King25EffectCountCombinationY.html',1,'osl::eval::ml']]],
  ['king25effectdefense',['King25EffectDefense',['../classosl_1_1eval_1_1ml_1_1King25EffectDefense.html',1,'osl::eval::ml']]],
  ['king25effecteach',['King25EffectEach',['../classosl_1_1eval_1_1ml_1_1King25EffectEach.html',1,'osl::eval::ml']]],
  ['king25effecteach_3c_200_20_3e',['King25EffectEach&lt; 0 &gt;',['../classosl_1_1eval_1_1ml_1_1King25EffectEach.html',1,'osl::eval::ml']]],
  ['king25effecteach_3c_201_20_3e',['King25EffectEach&lt; 1 &gt;',['../classosl_1_1eval_1_1ml_1_1King25EffectEach.html',1,'osl::eval::ml']]],
  ['king25effecteach_3c_202_20_3e',['King25EffectEach&lt; 2 &gt;',['../classosl_1_1eval_1_1ml_1_1King25EffectEach.html',1,'osl::eval::ml']]],
  ['king25effecteachboth',['King25EffectEachBoth',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBoth.html',1,'osl::eval::ml']]],
  ['king25effecteachbothending',['King25EffectEachBothEnding',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBoth.html#a3b28686e57cd92bcd05266473ef09d45',1,'osl::eval::ml::King25EffectEachBoth']]],
  ['king25effecteachbothending',['King25EffectEachBothEnding',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBothEnding.html',1,'osl::eval::ml']]],
  ['king25effecteachbothmidgame',['King25EffectEachBothMidgame',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBothMidgame.html',1,'osl::eval::ml']]],
  ['king25effecteachbothmidgame',['King25EffectEachBothMidgame',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBoth.html#a31787832059054ccae88c6e2d0e1b5e5',1,'osl::eval::ml::King25EffectEachBoth']]],
  ['king25effecteachbothmidgame2',['King25EffectEachBothMidgame2',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBothMidgame2.html',1,'osl::eval::ml']]],
  ['king25effecteachbothmidgame2',['King25EffectEachBothMidgame2',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBoth.html#ad1e13254a888cc5708128c267fa0b13a',1,'osl::eval::ml::King25EffectEachBoth']]],
  ['king25effecteachbothopening',['King25EffectEachBothOpening',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBothOpening.html',1,'osl::eval::ml']]],
  ['king25effecteachbothopening',['King25EffectEachBothOpening',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBoth.html#adb605fb2675dc0e59bb68cb94ce91d02',1,'osl::eval::ml::King25EffectEachBoth']]],
  ['king25effecteachending',['King25EffectEachEnding',['../classosl_1_1eval_1_1ml_1_1King25EffectEachEnding.html',1,'osl::eval::ml']]],
  ['king25effecteachkxy',['King25EffectEachKXY',['../classosl_1_1eval_1_1ml_1_1King25EffectEachKXY.html',1,'osl::eval::ml']]],
  ['king25effecteachkxy',['King25EffectEachKXY',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBoth.html#acdfa7517b29b7222b36031018d52cef8',1,'osl::eval::ml::King25EffectEachBoth']]],
  ['king25effecteachmidgame',['King25EffectEachMidgame',['../classosl_1_1eval_1_1ml_1_1King25EffectEachMidgame.html',1,'osl::eval::ml']]],
  ['king25effecteachopening',['King25EffectEachOpening',['../classosl_1_1eval_1_1ml_1_1King25EffectEachOpening.html',1,'osl::eval::ml']]],
  ['king25effecteachxy',['King25EffectEachXY',['../classosl_1_1eval_1_1ml_1_1King25EffectEachXY.html',1,'osl::eval::ml']]],
  ['king25effecteachxy',['King25EffectEachXY',['../classosl_1_1eval_1_1ml_1_1King25EffectEachBoth.html#a863daef6ea97b6654b2d90659ba2cced',1,'osl::eval::ml::King25EffectEachBoth']]],
  ['king25effectsupported',['King25EffectSupported',['../classosl_1_1eval_1_1ml_1_1King25EffectSupported.html',1,'osl::eval::ml']]],
  ['king25effectsupportedy',['King25EffectSupportedY',['../classosl_1_1eval_1_1ml_1_1King25EffectSupportedY.html',1,'osl::eval::ml']]],
  ['king25effecty',['King25EffectY',['../classosl_1_1eval_1_1ml_1_1King25EffectY.html',1,'osl::eval::ml']]],
  ['king25effecty2',['King25EffectY2',['../classosl_1_1eval_1_1ml_1_1King25EffectY2.html',1,'osl::eval::ml']]],
  ['king25effectyattack',['King25EffectYAttack',['../classosl_1_1eval_1_1ml_1_1King25EffectYAttack.html',1,'osl::eval::ml']]],
  ['king25effectydefense',['King25EffectYDefense',['../classosl_1_1eval_1_1ml_1_1King25EffectYDefense.html',1,'osl::eval::ml']]],
  ['king25emptyabs',['King25EmptyAbs',['../classosl_1_1eval_1_1ml_1_1King25EmptyAbs.html',1,'osl::eval::ml']]],
  ['king25emptyabs_3c_20false_20_3e',['King25EmptyAbs&lt; false &gt;',['../classosl_1_1eval_1_1ml_1_1King25EmptyAbs.html',1,'osl::eval::ml']]],
  ['king25emptyabs_3c_20true_20_3e',['King25EmptyAbs&lt; true &gt;',['../classosl_1_1eval_1_1ml_1_1King25EmptyAbs.html',1,'osl::eval::ml']]],
  ['king25emptyabsending',['King25EmptyAbsEnding',['../classosl_1_1eval_1_1ml_1_1King25EmptyAbsEnding.html',1,'osl::eval::ml']]],
  ['king25emptyabsopening',['King25EmptyAbsOpening',['../classosl_1_1eval_1_1ml_1_1King25EmptyAbsOpening.html',1,'osl::eval::ml']]],
  ['king25emptysquarenoeffect',['King25EmptySquareNoEffect',['../structosl_1_1eval_1_1ml_1_1King25EmptySquareNoEffect.html',1,'osl::eval::ml']]],
  ['king25emptysquarenoeffectending',['King25EmptySquareNoEffectEnding',['../classosl_1_1eval_1_1ml_1_1King25EmptySquareNoEffectEnding.html',1,'osl::eval::ml']]],
  ['king25emptysquarenoeffectopening',['King25EmptySquareNoEffectOpening',['../classosl_1_1eval_1_1ml_1_1King25EmptySquareNoEffectOpening.html',1,'osl::eval::ml']]],
  ['king25mobility',['King25Mobility',['../classosl_1_1eval_1_1ml_1_1King25Mobility.html',1,'osl::eval::ml']]],
  ['king25mobilityx',['King25MobilityX',['../classosl_1_1eval_1_1ml_1_1King25Mobility.html#a410a679d0ed1d713f1d9be5cbcacf688',1,'osl::eval::ml::King25Mobility']]],
  ['king25mobilityx',['King25MobilityX',['../classosl_1_1eval_1_1ml_1_1King25MobilityX.html',1,'osl::eval::ml']]],
  ['king25mobilityy',['King25MobilityY',['../classosl_1_1eval_1_1ml_1_1King25Mobility.html#aabcd85d14028548d354023c4353c6bf0',1,'osl::eval::ml::King25Mobility']]],
  ['king25mobilityy',['King25MobilityY',['../classosl_1_1eval_1_1ml_1_1King25MobilityY.html',1,'osl::eval::ml']]],
  ['king3pieces',['KING3PIECES',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238a9ee0c781fd717d6a1f19b11705af4c98',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo::KING3PIECES()'],['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#ae1056fde594bef9d8bdacd9eb346c398',1,'osl::eval::ml::OpenMidEndingEval::king3pieces()']]],
  ['king3pieces',['King3Pieces',['../classosl_1_1eval_1_1ml_1_1King3Pieces.html',1,'osl::eval::ml']]],
  ['king3piecesxy',['King3PiecesXY',['../classosl_1_1eval_1_1ml_1_1King3Pieces.html#ab5d98356d921e2aaafdd46d5577b1ee1',1,'osl::eval::ml::King3Pieces']]],
  ['king3piecesxy',['King3PiecesXY',['../classosl_1_1eval_1_1ml_1_1King3PiecesXY.html',1,'osl::eval::ml']]],
  ['king5x5ptype',['King5x5Ptype',['../classosl_1_1move__probability_1_1King5x5Ptype.html#ad95c3b1be92332b3b3d9fcfda9367ea6',1,'osl::move_probability::King5x5Ptype']]],
  ['king5x5ptype',['King5x5Ptype',['../classosl_1_1move__probability_1_1King5x5Ptype.html',1,'osl::move_probability']]],
  ['king8_5fattack_5fbonus',['king8_attack_bonus',['../structosl_1_1eval_1_1ProgressDebugInfo.html#aa915f517f17b9009acab8603777286d6',1,'osl::eval::ProgressDebugInfo']]],
  ['king8_5flong_5fpieces',['king8_long_pieces',['../structosl_1_1move__probability_1_1StateInfo.html#a6abfc5fc099820067f48cffe8955fc42',1,'osl::move_probability::StateInfo']]],
  ['king8effect',['King8Effect',['../classosl_1_1eval_1_1ml_1_1King8Effect.html',1,'osl::eval::ml']]],
  ['king8effectall',['King8EffectAll',['../classosl_1_1eval_1_1ml_1_1King8EffectAll.html#abc7fb0367b821d968fddc1b1d18273e9',1,'osl::eval::ml::King8EffectAll']]],
  ['king8effectall',['King8EffectAll',['../classosl_1_1eval_1_1ml_1_1King8EffectAll.html',1,'osl::eval::ml']]],
  ['king8effectbase',['King8EffectBase',['../classosl_1_1eval_1_1ml_1_1King8EffectBase.html',1,'osl::eval::ml']]],
  ['king8effectdefensesquare',['King8EffectDefenseSquare',['../classosl_1_1eval_1_1ml_1_1King8EffectDefenseSquare.html',1,'osl::eval::ml']]],
  ['king8effectdefensesquare_3c_20false_20_3e',['King8EffectDefenseSquare&lt; false &gt;',['../classosl_1_1eval_1_1ml_1_1King8EffectDefenseSquare.html',1,'osl::eval::ml']]],
  ['king8effectdefensesquare_3c_20true_20_3e',['King8EffectDefenseSquare&lt; true &gt;',['../classosl_1_1eval_1_1ml_1_1King8EffectDefenseSquare.html',1,'osl::eval::ml']]],
  ['king8effectdefensesquareboth',['King8EffectDefenseSquareBoth',['../classosl_1_1eval_1_1ml_1_1King8EffectDefenseSquareBoth.html',1,'osl::eval::ml']]],
  ['king8effectdefensesquareboth',['King8EffectDefenseSquareBoth',['../classosl_1_1eval_1_1ml_1_1King8EffectDefenseSquare.html#a505fbfc155640878720e12595b4f858c',1,'osl::eval::ml::King8EffectDefenseSquare']]],
  ['king8effectdefensesquareending',['King8EffectDefenseSquareEnding',['../structosl_1_1eval_1_1ml_1_1King8EffectDefenseSquareEnding.html',1,'osl::eval::ml']]],
  ['king8effectdefensesquareopening',['King8EffectDefenseSquareOpening',['../structosl_1_1eval_1_1ml_1_1King8EffectDefenseSquareOpening.html',1,'osl::eval::ml']]],
  ['king8effectemptysquare',['King8EffectEmptySquare',['../classosl_1_1eval_1_1ml_1_1King8EffectEmptySquare.html',1,'osl::eval::ml']]],
  ['king8effectemptysquare_3c_20false_20_3e',['King8EffectEmptySquare&lt; false &gt;',['../classosl_1_1eval_1_1ml_1_1King8EffectEmptySquare.html',1,'osl::eval::ml']]],
  ['king8effectemptysquare_3c_20true_20_3e',['King8EffectEmptySquare&lt; true &gt;',['../classosl_1_1eval_1_1ml_1_1King8EffectEmptySquare.html',1,'osl::eval::ml']]],
  ['king8effectemptysquareboth',['King8EffectEmptySquareBoth',['../classosl_1_1eval_1_1ml_1_1King8EffectEmptySquareBoth.html',1,'osl::eval::ml']]],
  ['king8effectemptysquareboth',['King8EffectEmptySquareBoth',['../classosl_1_1eval_1_1ml_1_1King8EffectEmptySquare.html#aefd3630b7ea5ff0a479e55ae9e0ec6a1',1,'osl::eval::ml::King8EffectEmptySquare']]],
  ['king8effectemptysquareending',['King8EffectEmptySquareEnding',['../structosl_1_1eval_1_1ml_1_1King8EffectEmptySquareEnding.html',1,'osl::eval::ml']]],
  ['king8effectemptysquareopening',['King8EffectEmptySquareOpening',['../structosl_1_1eval_1_1ml_1_1King8EffectEmptySquareOpening.html',1,'osl::eval::ml']]],
  ['king8group_2ecc',['king8Group.cc',['../king8Group_8cc.html',1,'']]],
  ['king8group_2eh',['king8Group.h',['../king8Group_8h.html',1,'']]],
  ['king8info',['King8Info',['../classosl_1_1checkmate_1_1King8Info.html',1,'osl::checkmate']]],
  ['king8info',['King8Info',['../classosl_1_1checkmate_1_1King8Info.html#a7a493a1a9b3538e70005a604e2cbcaa8',1,'osl::checkmate::King8Info::King8Info()'],['../structosl_1_1move__probability_1_1StateInfo.html#a308839cc6af37bdc8fc81243df94a196',1,'osl::move_probability::StateInfo::king8Info()'],['../classosl_1_1state_1_1NumEffectState.html#a7578d84f3c1975d11a19992d3081f80b',1,'osl::state::NumEffectState::king8Info()']]],
  ['king8info_2ecc',['king8Info.cc',['../king8Info_8cc.html',1,'']]],
  ['king8info_2eh',['king8Info.h',['../king8Info_8h.html',1,'']]],
  ['king8infos',['king8infos',['../classosl_1_1state_1_1NumEffectState.html#a6ba8b9279901490ffc240a25177e46cd',1,'osl::state::NumEffectState']]],
  ['king_5fescape',['KING_ESCAPE',['../classosl_1_1search_1_1MoveGenerator.html#a9e45ff047d15a655df790ef906a1d23ea9f457f3433cf1f33a4ff4ee2445c907e',1,'osl::search::MoveGenerator::KING_ESCAPE()'],['../structosl_1_1search_1_1QSearchTraits.html#a46468746eb6abad032e9185f85828c88a3b1fa2b7c8f76a496560f2ca1875ee47',1,'osl::search::QSearchTraits::KING_ESCAPE()']]],
  ['king_5fescape_5fhistogram',['king_escape_histogram',['../ratingstat_8cc.html#abb08b6bc1897ce11840a590378a0fb6a',1,'ratingstat.cc']]],
  ['king_5fmobility',['KING_MOBILITY',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238ab26ddbeb44328458f1bd392a5fab6274',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo::KING_MOBILITY()'],['../classosl_1_1state_1_1NumEffectState.html#a62b292b5d76ec5719bac73170dbd9ff2',1,'osl::state::NumEffectState::king_mobility()']]],
  ['king_5fpiece_5frelative',['KING_PIECE_RELATIVE',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238adcc5610eca48cc6e08e6438ef4d79343',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo']]],
  ['king_5fpiece_5frelative_5fnosupport',['KING_PIECE_RELATIVE_NOSUPPORT',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238a6d0e1cadabb8f8eda74b991df63cecfd',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo']]],
  ['king_5fpieces',['king_pieces',['../classosl_1_1record_1_1MiniBoard.html#a7bb4af6cc10bd6877efa0556ebf068aa',1,'osl::record::MiniBoard']]],
  ['king_5frelative_5fattack',['KING_RELATIVE_ATTACK',['../structosl_1_1progress_1_1ml_1_1NewProgressDebugInfo.html#ac429069d29b35fcb90fa2d7ca1930562a9a21113f24026421f632eed319bfec75',1,'osl::progress::ml::NewProgressDebugInfo::KING_RELATIVE_ATTACK()'],['../structosl_1_1progress_1_1ml_1_1NewProgressData.html#ab796fcea462755c2ca3645e92135d70f',1,'osl::progress::ml::NewProgressData::king_relative_attack()']]],
  ['king_5frelative_5fdefense',['KING_RELATIVE_DEFENSE',['../structosl_1_1progress_1_1ml_1_1NewProgressDebugInfo.html#ac429069d29b35fcb90fa2d7ca1930562a36e496e327d1be2ae48bc6cfa6c6c562',1,'osl::progress::ml::NewProgressDebugInfo::KING_RELATIVE_DEFENSE()'],['../structosl_1_1progress_1_1ml_1_1NewProgressData.html#a872402bdfbd5e249f0c03d197f28c34a',1,'osl::progress::ml::NewProgressData::king_relative_defense()']]],
  ['king_5frelative_5fweight',['king_relative_weight',['../classosl_1_1progress_1_1ml_1_1NewProgress.html#ae464f814a81804e8e5e0fbae79dd41e1',1,'osl::progress::ml::NewProgress']]],
  ['king_5frook_5fbishop',['KING_ROOK_BISHOP',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238a2df34f4e180738808558bb9e6f2919c2',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo::KING_ROOK_BISHOP()'],['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#acebb55d8f90a78c9994c8d62fa20fda3',1,'osl::eval::ml::OpenMidEndingEval::king_rook_bishop()']]],
  ['king_5fstatus',['king_status',['../classosl_1_1search_1_1DualThreatmateState.html#a341d0db50cc5f3263186d11a1083c467',1,'osl::search::DualThreatmateState']]],
  ['king_5ftable',['king_table',['../classosl_1_1eval_1_1ml_1_1BishopHead.html#aff9a030496b2c1c4e4e69521b4fbc8b4',1,'osl::eval::ml::BishopHead::king_table()'],['../classosl_1_1eval_1_1ml_1_1NonPawnAttacked.html#a779c11e8c53c89e3c909cae55383f506',1,'osl::eval::ml::NonPawnAttacked::king_table()']]],
  ['king_5ftable_5fvalue',['king_table_value',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a19cf0d4d443999830bef053e0808e06f',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['king_5fx_5fblocked3',['KING_X_BLOCKED3',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238ae5300a4890f3bdd96327c25c15b87b31',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo']]],
  ['kingarray',['KingArray',['../classosl_1_1record_1_1MiniBoard.html#ad6811d6068547960faf8ab119abeba5d',1,'osl::record::MiniBoard']]],
  ['kingblockade',['KingBlockade',['../classosl_1_1move__probability_1_1KingBlockade.html',1,'osl::move_probability']]],
  ['kingblockade',['KingBlockade',['../classosl_1_1move__probability_1_1KingBlockade.html#ab61136eecf63e2479088e565a26eb046',1,'osl::move_probability::KingBlockade']]],
  ['kingescape',['KingEscape',['../classosl_1_1rating_1_1KingEscape.html',1,'osl::rating']]],
  ['kingescape',['KingEscape',['../classosl_1_1search_1_1AlphaBeta3.html#a1cd6db8daa5d6a3faa04681a697ef332a963b4f4a777f48aec766f7beb69cad26',1,'osl::search::AlphaBeta3::KingEscape()'],['../classosl_1_1rating_1_1KingEscape.html#a4dc62543276eb52a457e93385a66c118',1,'osl::rating::KingEscape::KingEscape()']]],
  ['kingescape_5forder',['kingescape_order',['../ratingstat_8cc.html#acf94cd17bd622a9becfc3d35f6cfb5ae',1,'ratingstat.cc']]],
  ['kingescape_5forder_5fall',['kingescape_order_all',['../ratingstat_8cc.html#a3e9ca19691651f9a2916d45c4f2407cf',1,'ratingstat.cc']]],
  ['kingescape_5forder_5fselected',['kingescape_order_selected',['../ratingstat_8cc.html#af9351a84d6983312d404c98c77fe7c02',1,'ratingstat.cc']]],
  ['kingescapegroup',['KingEscapeGroup',['../classosl_1_1rating_1_1KingEscapeGroup.html',1,'osl::rating']]],
  ['kingescapegroup',['KingEscapeGroup',['../classosl_1_1rating_1_1KingEscapeGroup.html#ab20fe464ab96d71b17c13ddffb31e233',1,'osl::rating::KingEscapeGroup']]],
  ['kingindex',['kingIndex',['../classosl_1_1eval_1_1endgame_1_1KingPieceTable.html#aa6b8db3d022f371d2b0eb8b5255b9231',1,'osl::eval::endgame::KingPieceTable']]],
  ['kingmobility',['KingMobility',['../classosl_1_1eval_1_1ml_1_1KingMobility.html',1,'osl::eval::ml']]],
  ['kingmobility',['KingMobility',['../classosl_1_1mobility_1_1KingMobility.html',1,'osl::mobility']]],
  ['kingmobility',['KingMobility',['../classosl_1_1mobility_1_1KingMobility.html#aea14679aab6ec2b6be8a8969fc58e3fa',1,'osl::mobility::KingMobility']]],
  ['kingmobility_2eh',['kingMobility.h',['../kingMobility_8h.html',1,'']]],
  ['kingmobilityabs',['kingMobilityAbs',['../classosl_1_1state_1_1NumEffectState.html#a8058d0b40f4d6e381d9c09f2404f8a4e',1,'osl::state::NumEffectState']]],
  ['kingmobilityofplayer',['kingMobilityOfPlayer',['../classosl_1_1state_1_1NumEffectState.html#a65bea914a85d99f148a9dab90e651317',1,'osl::state::NumEffectState']]],
  ['kingmobilitysum',['KingMobilitySum',['../classosl_1_1eval_1_1ml_1_1KingMobilitySum.html',1,'osl::eval::ml']]],
  ['kingmobilitywithbishop',['KingMobilityWithBishop',['../classosl_1_1eval_1_1ml_1_1KingMobility.html#a2f56838bb15486e90651c424edb53aa4',1,'osl::eval::ml::KingMobility']]],
  ['kingmobilitywithbishop',['KingMobilityWithBishop',['../classosl_1_1eval_1_1ml_1_1KingMobilityWithBishop.html',1,'osl::eval::ml']]],
  ['kingmobilitywithrook',['KingMobilityWithRook',['../classosl_1_1eval_1_1ml_1_1KingMobilityWithRook.html',1,'osl::eval::ml']]],
  ['kingmobilitywithrook',['KingMobilityWithRook',['../classosl_1_1eval_1_1ml_1_1KingMobility.html#af3c9ed0005e6444e0e44d2680821fd37',1,'osl::eval::ml::KingMobility']]],
  ['kingmovebase',['KingMoveBase',['../classosl_1_1move__probability_1_1BreakThreatmate.html#a11d13e9c16f4109ded2564591c40b799ac932adfce9292a358136aa87d3eff303',1,'osl::move_probability::BreakThreatmate']]],
  ['kingmovesize',['KingMoveSize',['../classosl_1_1move__probability_1_1BreakThreatmate.html#a11d13e9c16f4109ded2564591c40b799a65590f8126a1a5abd490314194e53cbd',1,'osl::move_probability::BreakThreatmate']]],
  ['kingopenmove',['KingOpenMove',['../structosl_1_1move__classifier_1_1KingOpenMove.html',1,'osl::move_classifier']]],
  ['kingopenmove_2ecc',['kingOpenMove.cc',['../kingOpenMove_8cc.html',1,'']]],
  ['kingopenmove_2eh',['kingOpenMove.h',['../kingOpenMove_8h.html',1,'']]],
  ['kingpiece',['kingPiece',['../classosl_1_1state_1_1SimpleState.html#abc1450be143fe0d042705151b40df297',1,'osl::state::SimpleState::kingPiece() const '],['../classosl_1_1state_1_1SimpleState.html#a4fa3945b52116ff27f6869ac12d1eb0f',1,'osl::state::SimpleState::kingPiece(Player P) const ']]],
  ['kingpiecerelative',['KingPieceRelative',['../structosl_1_1eval_1_1ml_1_1KingPieceRelative.html',1,'osl::eval::ml']]],
  ['kingpiecerelativenosupport',['KingPieceRelativeNoSupport',['../classosl_1_1eval_1_1ml_1_1KingPieceRelativeNoSupport.html',1,'osl::eval::ml']]],
  ['kingpiecetable',['KingPieceTable',['../classosl_1_1eval_1_1endgame_1_1KingPieceTable.html#a10b128de4d87d5e5005e618415238fe3',1,'osl::eval::endgame::KingPieceTable']]],
  ['kingpiecetable',['KingPieceTable',['../classosl_1_1eval_1_1endgame_1_1KingPieceTable.html',1,'osl::eval::endgame']]],
  ['kingpiecetable_2ecc',['kingPieceTable.cc',['../kingPieceTable_8cc.html',1,'']]],
  ['kingpiecetable_2eh',['kingPieceTable.h',['../kingPieceTable_8h.html',1,'']]],
  ['kingpiecevalues',['KingPieceValues',['../structosl_1_1eval_1_1endgame_1_1KingPieceValues.html',1,'osl::eval::endgame']]],
  ['kingpiecevalues_2eh',['kingPieceValues.h',['../kingPieceValues_8h.html',1,'']]],
  ['kingrelativex',['KingRelativeX',['../classosl_1_1move__probability_1_1KingRelativeX.html#afdee00a2e55a7e3f28b61f67773a5a16',1,'osl::move_probability::KingRelativeX']]],
  ['kingrelativex',['KingRelativeX',['../classosl_1_1move__probability_1_1KingRelativeX.html',1,'osl::move_probability']]],
  ['kingrelativey',['KingRelativeY',['../classosl_1_1move__probability_1_1KingRelativeY.html',1,'osl::move_probability']]],
  ['kingrelativey',['KingRelativeY',['../classosl_1_1move__probability_1_1KingRelativeY.html#ac5ff26dfb22e5d2c7b9843ba010dec80',1,'osl::move_probability::KingRelativeY']]],
  ['kingrookbishop',['KingRookBishop',['../classosl_1_1eval_1_1ml_1_1KingRookBishop.html',1,'osl::eval::ml']]],
  ['kingsquare',['kingSquare',['../classosl_1_1state_1_1SimpleState.html#a3434f38d2d324d6eba7036de5030ee8a',1,'osl::state::SimpleState::kingSquare() const '],['../classosl_1_1state_1_1SimpleState.html#a8a57984be4792405d86efe61958ea74f',1,'osl::state::SimpleState::kingSquare(Player player) const ']]],
  ['kingtable_2ecc',['kingTable.cc',['../kingTable_8cc.html',1,'']]],
  ['kingtable_2eh',['kingTable.h',['../kingTable_8h.html',1,'']]],
  ['kingtraits',['KingTraits',['../structosl_1_1KingTraits.html',1,'osl']]],
  ['kingwalk',['kingWalk',['../structosl_1_1search_1_1QuiescenceGenerator.html#a3f13e7cfe35c2d8049fc19dd0d5a8222',1,'osl::search::QuiescenceGenerator']]],
  ['kingwalk',['KingWalk',['../structosl_1_1move__generator_1_1KingWalk.html',1,'osl::move_generator']]],
  ['kingwalk_2eh',['kingWalk.h',['../kingWalk_8h.html',1,'']]],
  ['kingx_5fblocked',['kingx_blocked',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#ab89fa8f61df9b83dac88f75dd3d273d8',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['kingxblocked',['KingXBlocked',['../classosl_1_1eval_1_1ml_1_1KingXBlocked.html',1,'osl::eval::ml']]],
  ['kingxblocked3',['KingXBlocked3',['../classosl_1_1eval_1_1ml_1_1KingXBlocked3.html',1,'osl::eval::ml']]],
  ['kingxblocked3y',['KingXBlocked3Y',['../classosl_1_1eval_1_1ml_1_1KingXBlocked3Y.html',1,'osl::eval::ml']]],
  ['kingxblocked3y',['KingXBlocked3Y',['../classosl_1_1eval_1_1ml_1_1KingXBlocked3.html#ab838ff6c44a8f426f1541e73472152fe',1,'osl::eval::ml::KingXBlocked3']]],
  ['kingxblockedbase',['KingXBlockedBase',['../structosl_1_1eval_1_1ml_1_1KingXBlockedBase.html',1,'osl::eval::ml']]],
  ['kingxblockedboth',['KingXBlockedBoth',['../classosl_1_1eval_1_1ml_1_1KingXBlocked.html#a0d4ff604a4273246c7e2ab5c56891b93',1,'osl::eval::ml::KingXBlocked::KingXBlockedBoth()'],['../classosl_1_1eval_1_1ml_1_1KingXBlockedY.html#a0d4ff604a4273246c7e2ab5c56891b93',1,'osl::eval::ml::KingXBlockedY::KingXBlockedBoth()']]],
  ['kingxblockedboth',['KingXBlockedBoth',['../classosl_1_1eval_1_1ml_1_1KingXBlockedBoth.html',1,'osl::eval::ml']]],
  ['kingxblockedy',['KingXBlockedY',['../classosl_1_1eval_1_1ml_1_1KingXBlockedY.html',1,'osl::eval::ml']]],
  ['kingxblockedybase',['KingXBlockedYBase',['../classosl_1_1eval_1_1ml_1_1KingXBlocked.html#a09f923f9f2add7ef70d1d96ed8be6ffb',1,'osl::eval::ml::KingXBlocked::KingXBlockedYBase()'],['../classosl_1_1eval_1_1ml_1_1KingXBlockedY.html#a09f923f9f2add7ef70d1d96ed8be6ffb',1,'osl::eval::ml::KingXBlockedY::KingXBlockedYBase()'],['../classosl_1_1eval_1_1ml_1_1KingXBothBlocked.html#a09f923f9f2add7ef70d1d96ed8be6ffb',1,'osl::eval::ml::KingXBothBlocked::KingXBlockedYBase()'],['../classosl_1_1eval_1_1ml_1_1KingXBothBlockedY.html#a09f923f9f2add7ef70d1d96ed8be6ffb',1,'osl::eval::ml::KingXBothBlockedY::KingXBlockedYBase()']]],
  ['kingxblockedybase',['KingXBlockedYBase',['../classosl_1_1eval_1_1ml_1_1KingXBlockedYBase.html',1,'osl::eval::ml']]],
  ['kingxbothblocked',['KingXBothBlocked',['../classosl_1_1eval_1_1ml_1_1KingXBothBlocked.html',1,'osl::eval::ml']]],
  ['kingxbothblocked',['KingXBothBlocked',['../classosl_1_1eval_1_1ml_1_1KingXBothBlockedY.html#a37379553fa9850604327cf58615ab087',1,'osl::eval::ml::KingXBothBlockedY']]],
  ['kingxbothblockedy',['KingXBothBlockedY',['../classosl_1_1eval_1_1ml_1_1KingXBothBlockedY.html',1,'osl::eval::ml']]],
  ['kisen_2dto_2dcsa_2ecc',['kisen-to-csa.cc',['../kisen-to-csa_8cc.html',1,'']]],
  ['kisen_2ecc',['kisen.cc',['../kisen_8cc.html',1,'']]],
  ['kisen_2eh',['kisen.h',['../kisen_8h.html',1,'']]],
  ['kisen_5ffilename',['kisen_filename',['../classosl_1_1rating_1_1BradleyTerry.html#a1d7c7a857bff7d91a532c811ecaf08a2',1,'osl::rating::BradleyTerry::kisen_filename()'],['../probability_8cc.html#a7d206154015344334542008b65b9a110',1,'kisen_filename():&#160;probability.cc'],['../ratingstat_8cc.html#a7d206154015344334542008b65b9a110',1,'kisen_filename():&#160;ratingstat.cc']]],
  ['kisen_5fstart',['kisen_start',['../classosl_1_1rating_1_1BradleyTerry.html#adb84216c75da157172c0beae9901d122',1,'osl::rating::BradleyTerry::kisen_start()'],['../ratingstat_8cc.html#a986af9c47cde7151fd744d6b235d3d14',1,'kisen_start():&#160;ratingstat.cc']]],
  ['kisenfile',['KisenFile',['../classosl_1_1record_1_1KisenFile.html',1,'osl::record']]],
  ['kisenfile',['KisenFile',['../classosl_1_1record_1_1KisenFile.html#ad0770532a571a085a763d6552b9cb16f',1,'osl::record::KisenFile']]],
  ['kisenipxfile',['KisenIpxFile',['../classosl_1_1record_1_1KisenIpxFile.html',1,'osl::record']]],
  ['kisenipxfile',['KisenIpxFile',['../classosl_1_1record_1_1KisenIpxFile.html#a9acd54a68941c09080fa4986c00725b5',1,'osl::record::KisenIpxFile']]],
  ['kisenipxwriter',['KisenIpxWriter',['../classosl_1_1record_1_1KisenIpxWriter.html#ad0c499b4ba74577ee2816b3e9db6b7e6',1,'osl::record::KisenIpxWriter']]],
  ['kisenipxwriter',['KisenIpxWriter',['../classosl_1_1record_1_1KisenIpxWriter.html',1,'osl::record']]],
  ['kisenplusfile',['KisenPlusFile',['../classosl_1_1record_1_1KisenPlusFile.html#ac7698725053b5ce6548e8c9e351146cb',1,'osl::record::KisenPlusFile']]],
  ['kisenplusfile',['KisenPlusFile',['../classosl_1_1record_1_1KisenPlusFile.html',1,'osl::record']]],
  ['kisenrecord',['kisenRecord',['../classosl_1_1game__playing_1_1RecordTracer.html#a0c3df6d7f38b4a4d28d5086e8ea73f1a',1,'osl::game_playing::RecordTracer']]],
  ['kisenutils',['KisenUtils',['../classosl_1_1record_1_1KisenUtils.html',1,'osl::record']]],
  ['kishimoto_5fwiden_5fthreshold',['KISHIMOTO_WIDEN_THRESHOLD',['../dfpn_8cc.html#a24db82a782c79da3b5564b82826b8cd1',1,'dfpn.cc']]],
  ['kmove',['kmove',['../classosl_1_1record_1_1ki2_1_1InputStream.html#af78116db5d99c09a067130df2155fa1b',1,'osl::record::ki2::InputStream']]],
  ['knight',['KNIGHT',['../namespaceosl.html#a0a6e5b44dc90a9ee7b40ddce1e90b660a88d702c2a2b5853b95bb002c3753f78a',1,'osl']]],
  ['knight2step',['knight2Step',['../classosl_1_1rating_1_1Threatmate.html#a9083bd0954ac0dd3a512a1b1f35b9b25',1,'osl::rating::Threatmate']]],
  ['knight_5fadvance',['knight_advance',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#aeba406eec6c99383a0400c27357a32e9',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5fbonus',['knight_bonus',['../structosl_1_1eval_1_1MinorPieceDebugInfo.html#a1ce25ac27db449a3fedd83d5d350215c',1,'osl::eval::MinorPieceDebugInfo']]],
  ['knight_5fcheck',['KNIGHT_CHECK',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238a1b3978e53c0891713f35f721de1eb272',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo::KNIGHT_CHECK()'],['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a764c08e418edc7b632d708c163337ffa',1,'osl::eval::ml::OpenMidEndingEval::knight_check()']]],
  ['knight_5fcheck_5fbonus',['knight_check_bonus',['../structosl_1_1eval_1_1ProgressDebugInfo.html#a12766e07d3848aa0470e14f1a84e72f4',1,'osl::eval::ProgressDebugInfo']]],
  ['knight_5fdrop',['knight_drop',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a9565549637d50a8a90b560569fdb45c1',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5ffork_5fsquares',['knight_fork_squares',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#aef07b44ed27f2c85681175bc5378162c',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5fhead',['KNIGHT_HEAD',['../structosl_1_1eval_1_1ml_1_1OpenMidEndingEvalDebugInfo.html#a967aaffb15705b668cf4568907eec238a8426b946e8a907a34208b846cc60a8ac',1,'osl::eval::ml::OpenMidEndingEvalDebugInfo::KNIGHT_HEAD()'],['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a80203477136176d1fdfda0cc4beaa0ae',1,'osl::eval::ml::OpenMidEndingEval::knight_head()']]],
  ['knight_5fon_5fstand',['knight_on_stand',['../classosl_1_1eval_1_1MinorPieceBonus.html#a2edbb8b0bea77db4f87100183f5e8dc4',1,'osl::eval::MinorPieceBonus']]],
  ['knight_5fpieces',['knight_pieces',['../classosl_1_1record_1_1MiniBoard.html#a7b1f0fa9a42ec524d6c0df9813234947',1,'osl::record::MiniBoard']]],
  ['knight_5ftable',['knight_table',['../classosl_1_1eval_1_1ml_1_1GoldFeatures.html#addd0581a233acd454a6dc0ad67895865',1,'osl::eval::ml::GoldFeatures']]],
  ['knightadvance',['KnightAdvance',['../classosl_1_1eval_1_1ml_1_1KnightAdvance.html',1,'osl::eval::ml']]],
  ['knightarray',['KnightArray',['../classosl_1_1record_1_1MiniBoard.html#abc38b9338842a8b82ea3a07d1648cd39',1,'osl::record::MiniBoard']]],
  ['knightbonus',['knightBonus',['../classosl_1_1eval_1_1MinorPieceBonus.html#adffb6da5f54c8feaa0569c318131eeb3',1,'osl::eval::MinorPieceBonus']]],
  ['knightcapturedepth',['KnightCaptureDepth',['../structosl_1_1search_1_1QSearch2PrivateTraits.html#af9e170917970a4031f4f81ce7bd5e761ab26229305ecbe95dbf3b1eda7a3f2bda',1,'osl::search::QSearch2PrivateTraits']]],
  ['knightcheck',['KnightCheck',['../classosl_1_1eval_1_1ml_1_1KnightCheck.html',1,'osl::eval::ml']]],
  ['knightchecky',['KnightCheckY',['../classosl_1_1eval_1_1ml_1_1KnightCheckY.html',1,'osl::eval::ml']]],
  ['knightchecky',['KnightCheckY',['../classosl_1_1eval_1_1ml_1_1KnightCheck.html#aedd90aadef0c58d28808bc752e8c8398',1,'osl::eval::ml::KnightCheck']]],
  ['knightfork',['KnightFork',['../classosl_1_1eval_1_1ml_1_1KnightFork.html',1,'osl::eval::ml']]],
  ['knighthead',['KnightHead',['../classosl_1_1eval_1_1ml_1_1KnightHead.html',1,'osl::eval::ml']]],
  ['knightheadopppiecepawnonstand',['KnightHeadOppPiecePawnOnStand',['../classosl_1_1eval_1_1ml_1_1KnightHeadOppPiecePawnOnStand.html',1,'osl::eval::ml']]],
  ['knightheadopppiecepawnonstand',['KnightHeadOppPiecePawnOnStand',['../classosl_1_1eval_1_1ml_1_1KnightHead.html#a2ef528e51c8bc1684dd336af06ae8fbe',1,'osl::eval::ml::KnightHead']]]
];
